overrep_test: overrep_test

Description Usage Arguments Value Examples

View source: R/overrepresentation_test.r

Description

Overrepresentation test - Functional (usually gene ontology) analysis

Usage

1
2
3
overrep_test(categories, query_genes, bg_genes, min_query = 3,
  pval_threshold = 0.05, ease = TRUE, sig_digits = 4,
  mult_test = TRUE, super_strict = FALSE)

Arguments

categories

list of named character vectors containing the functional groups. Each vector should contain gene names or IDs. The name of each vector should be the functional category.

query_genes

character vector of gene names

bg_genes

character vector of gene names to use as the background set containing genes and associated information including location of genes

min_query

minimum number of query genes in the category for it be tested, no point having a category with one query gene in it

pval_threshold

p value threshold. Only results with p-value/corrected p-value less than this thrreshold will be returned.

mult_test

apply multiple testing correction (Benjamini-Hochberg FDR is used) and use the corrected value to filter for significant results. This should usually be set to TRUE (default). If set to false, the correction is still applied but the uncorrected pvalue is used to filter by.

super_strict

stricter pvalue correction where it takes the number of tests as being the total number of functional categories. By default the number of tests corrected for is only the number of functional categories that contain

min_query genes

Value

results of functional overrepresentation test. If no categories have a p-value <= pval_threshold a NULL object will be returned.

Examples

1
2
go_results <- overrep_test(all_go_categories, genes_1, bg_genes)
head(go_results)

laurabiggins/GOcategoryStats documentation built on Oct. 27, 2019, 11:36 a.m.