process_GMT: Import and process GMT file.

Description Usage Arguments Details Value Examples

View source: R/process_files.r

Description

Import GMT file containing gene sets.

Usage

1
process_GMT(file, min_genes = 3, max_genes = 5000)

Arguments

file

file path for gmt file containing gene sets

min_genes

minimum number of genes required in the functional category for the category to be loaded.

max_genes

maximum number of genes required in the functional category for the category to be loaded.

Details

The GMT format is described GMT format. The first column should contain gene set names, the 2nd column contains a brief description and the 3rd column contains a whitespace separated list of genes.

Value

A named list containing all the gene sets imported from gmt_file_path

Examples

1
2
file <- "http://download.baderlab.org/EM_Genesets/current_release/Mouse/symbol/Mouse_GO_AllPathways_no_GO_iea_December_01_2018_symbol.gmt"
x <- process_GMT(file, 5, 5000)

laurabiggins/GOcategoryStats documentation built on Oct. 27, 2019, 11:36 a.m.